Learn R Programming

MCI (version 1.2.0)

MCI-package: Multiplicative Competitive Interaction (MCI) Model

Description

The Multiplicative Competitive Interaction (MCI) Model (Nakanishi/Cooper 1974) is an econometric model for analyzing market shares and/or market areas in a competitive environment where the market is divided in $i$ submarkets (e.g. groups of customers, time periods or geographical regions) and served by $j$ suppliers (e.g. firms, brands or locations). The explained/response variable of the model is $p_{ij}$, the market shares of $j$ in $i$, which are logically consistent (that means: 0 < $p_{ij}$ < 1, $\sum_{j=1}^n{p_{ij} = 1}$). The market shares depend on the attractivity/utility of the alternative $j$ in the choice situation/submarket $i$, $A_{ij}$ resp. $U_{ij}$. The model is non-linear (multiplicative attractivity/utility function with exponential weighting) but can be transformed to be estimated by OLS (ordinary least squares) regression using the multi-step log-centering transformation. Before the log-centering transformation can be applied, which is required for fitting the model, also a re-arrangement of the raw data (e.g. household surveys) in an interaction matrix is necessary. The MCI model is a special case of market share model (which fulfills the requirement of logical consistency in the output), but can especially be used as a market area model (or spatial MCI model) in retail location analysis because it is also an econometric approach to estimate the parameters of the popular Huff model for market areas (Huff 1962). The functions in this package include fitting the MCI model, MCI shares simulations, the log-centering transformation of MCI datasets, creation of interaction matrices from empirical raw data and several tools for data preparation. Additionally, the package provides applications for the Huff model, including a non-linear fitting algorithm for the local optimization of the attractivity values.

Arguments

References

Cooper, L. G./Nakanishi, M. (1988): “Market-Share Analysis: Evaluating competitive marketing effectiveness”. Boston, Dordrecht, London : Kluwer. Digital version from 2010: http://www.anderson.ucla.edu/faculty/lee.cooper/MCI_Book/BOOKI2010.pdf

Cliquet, G. (2006): “Retail Location Models”. In: Cliquet, G. (ed.): Geomarketing. Models and Strategies in Spatial Marketing. London : ISTE. p. 137-163.

Guessefeldt, J. (2002): “Zur Modellierung von raeumlichen Kaufkraftstroemen in unvollkommenen Maerkten”. In: Erdkunde, 56, 4, p. 351-370.

Huff, D. L. (1962): “Determination of Intra-Urban Retail Trade Areas”. Los Angeles : University of California.

Huff, D. L./Batsell, R. R. (1975): “Conceptual and Operational Problems with Market Share Models of Consumer Spatial Behavior”. In: Advances in Consumer Research, 2, p. 165-172.

Huff, D. L./McCallum, D. (2008): “Calibrating the Huff Model Using ArcGIS Business Analyst”. ESRI White Paper, September 2008. https://www.esri.com/library/whitepapers/pdfs/calibrating-huff-model.pdf

Nakanishi, M./Cooper, L. G. (1974): “Parameter Estimation for a Multiplicative Competitive Interaction Model - Least Squares Approach”. In: Journal of Marketing Research, 11, 3, p. 303-311.

Nakanishi, M./Cooper, L. G. (1982): “Simplified Estimation Procedures for MCI Models”. In: Marketing Science, 1, 3, p. 314-322.

Wieland, T. (2015): “Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens”. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.