Learn R Programming

MCI (version 1.0.1)

ce: Market areas of consumer electronic stores

Description

Market areas of five consumer electronic (CE) stores in a german study area and their explanatory variables. The market areas (or local market shares) are generated from a representative household survey from 2012. The other variables were gathered and/or calculated at the same time (by mapping stores etc.). The survey dataset contains 95 cases ($i$ = 19 submarkets x $j$ = 5 suppliers).

Usage

data("ce")

Arguments

source

Wieland, T. (2015): Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.

References

Wieland, T. (2015): Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.

Examples

Run this code
data(ce)
# Loads the data

mymcimodel <- mci.fit (ce, "origin_code", "store_code", "ms_obs", "traveltime", 
"salesarea", "conc_all", "conc_comp")
# Save the results in new lm object
summary(mymcimodel)
# Summary of the model

Run the code above in your browser using DataLab