Learn R Programming

MCI (version 1.2.0)

grocery1: Grocery store choices in Goettingen

Description

Results from a POS survey in Goettingen (Germany) from June 2015 (raw data). Amongst other things, the participants were asked about their last grocery shopping trip (store choice and expenditures) and their place of residence (ZIP code). The survey dataset contains 179 cases/interviewed individuals. The survey is not representative and should be regarded as an example.

Usage

data("grocery1")

Arguments

Format

A data frame with 179 observations on the following 5 variables.

Wieland, T. (2011): “Nahversorgung mit Lebensmitteln in Goettingen 2011 - Eine Analyse der Angebotssituation im Goettinger Lebensmitteleinzelhandel unter besonderer Beruecksichtigung der Versorgungsqualitaet”. Goettinger Statistik Aktuell, 35. Goettingen. http://www.goesis.goettingen.de/pdf/Aktuell35.pdf Primary empirical sources: POS (point of sale) survey in the authors' course (“Seminar Angewandte Geographie 1: Stadtentwicklung und Citymarketing an einem konkreten Fallbeispiel”, University of Goettingen/Institute of Geography, June 2015), own calculations

See Also

grocery2

Examples

Run this code
data(grocery1)
# Loads the data
ijmatrix.create (grocery1, "plz_submarket", "store_code")
# Creates an interaction table with local market shares 

Run the code above in your browser using DataLab