Learn R Programming

MCI (version 1.2.0)

grocery2: Grocery store market areas in Goettingen

Description

Market areas of grocery stores in Goettingen, generated from a POS survey in Goettingen (Germany) from June 2015. The survey dataset contains 224 cases ($i$ = 7 submarkets x $j$ = 32 suppliers). The data is the result of a survey that is not representative (see grocery1) and also biased due to the data preparation. The data should be regarded as an example.

Usage

data("grocery2")

Arguments

Format

A data frame with 224 observations on the following 8 variables.

DISQ (Deutsches Institut fuer Servicequalitaet) (2015) “Discounter guenstig, Vollsortimenter serviceorientiert. Studie Lebensmittelmaerkte (15.10.2015)”. http://disq.de/2015/20151015-Lebensmittelmaerkte.html Wieland, T. (2011): “Nahversorgung mit Lebensmitteln in Goettingen 2011 - Eine Analyse der Angebotssituation im Goettinger Lebensmitteleinzelhandel unter besonderer Beruecksichtigung der Versorgungsqualitaet”. Goettinger Statistik Aktuell, 35. Goettingen. http://www.goesis.goettingen.de/pdf/Aktuell35.pdf Primary empirical sources: POS (point of sale) survey in the authors' course (“Seminar Angewandte Geographie 1: Stadtentwicklung und Citymarketing an einem konkreten Fallbeispiel”, University of Goettingen/Institute of Geography, June 2015), own calculations

See Also

grocery1

Examples

Run this code
data(grocery2)
# Loads the data
mci.transmat (grocery2, "plz_submarket", "store_code", "p_ij_obs", "dist_km", "salesarea_qm")
# Applies the log-centering transformation to the dataset using the function mci.transmat

Run the code above in your browser using DataLab