Learn R Programming

MCI (version 1.2.0)

huff.decay: Distance decay function in the Huff model

Description

This function estimates a distance decay function from observed data and compares different function types

Usage

huff.decay(dataset, x, y, plots = FALSE)

Arguments

dataset
A data.frame containing the observed interaction data and the transport costs
x
A numeric vector containing the independent variable, the transport costs (e.g. traveling time or street distance)
y
A numeric vector containing the dependent variable, the interaction measure (e.g. local market shares, trip volume, visitors per capita)
plots
logical argument that indicates if the curves are plotted

Value

A data.frame containing the function parameters (Intercept, Slope), their p values in the regression function (p Intercept, p Slope) and fitting measures (R-Squared, Adj. R-Squared). Additionally, a plot of the four estimated functions and the observed data.

Details

The distance decay function is a classic concept in quantitative economic geography and describes the relationship between transport costs and trip volume between origins ($i$) and a destination ($j$). The dependent variable is an indicator of trip volume, such as local market shares or visitors per capita etc., which are explained by the transport costs between all $i$ and the destination $j$, $d_{ij}$. The non-linear modeling of transport costs is also a key concept of the Huff model (see the function huff.shares). This function estimates and compares different types of possible distance decay functions (linear, power, exponential, logistic) based on observed interaction data.

References

Huff, D. L. (1962): “Determination of Intra-Urban Retail Trade Areas”. Los Angeles : University of California.

Huff, D. L. (1963): “A Probabilistic Analysis of Shopping Center Trade Areas”. In: Land Economics, 39, 1, p. 81-90.

Huff, D. L. (1964): “Defining and Estimating a Trading Area”. In: Journal of Marketing, 28, 4, p. 34-38.

Isard, W. (1960): “Methods of Regional Analysis: an Introduction to Regional Science”. Cambridge.

Kanhaeusser, C. (2007): “Modellierung und Prognose von Marktgebieten am Beispiel des Moebeleinzelhandels”. In: Klein, R./Rauh, J. (eds.): Analysemethodik und Modellierung in der geographischen Handelsforschung. Geographische Handelsforschung, 13. Passau. p. 75-110.

Loeffler, G. (1998): “Market areas - a methodological reflection on their boundaries”. In: GeoJournal, 45, 4, p. 265-272.

See Also

huff.shares, huff.attrac, huff.fit, mci.fit

Examples

Run this code
data(ce)
# Loads the data
huff.decay (ce[ce$store_code=="E04",], "traveltime", "ms_obs")
# Distance decay function for the store E01 in dataset ce
# returns the model results as data frame and plot

Run the code above in your browser using DataLab