Learn R Programming

MCI (version 1.0.1)

ijmatrix.shares: Market shares in interaction matrix

Description

Calculating market shares in an interaction matrix based on the observations of the regarded variable.

Usage

ijmatrix.shares(rawmatrix, submarkets, suppliers, observations)

Arguments

rawmatrix
a data.frame containing the submarkets, suppliers and the observed data
submarkets
the column in the dataset containing the submarkets (e.g. ZIP codes), should be a factor
suppliers
the column in the dataset containing the suppliers (e.g. store codes), should be a factor
observations
the column with the regarded variable (e.g. frequencies, expenditures, turnovers)

Value

  • The input interaction matrix which is a data.frame with a new column 'p_ij_obs' or, if used after ijmatrix.create, an update of the columns 'freq_i_total' and 'p_ij_obs'.

Details

This function calculates the market shares of every $j$ in every $i$ ($p_{ij}$) based on an existing interaction matrix. In the MCI model the dependent variable is the market share of the $j$ suppliers in the $i$ submarkets, in which the shares are logically consistent (that means: 0 < $p_{ij}$ < 1, $\sum_{j=1}^n{p_{ij} = 1}$).

References

Cooper, L. G./Nakanishi, M. (1988): Market-Share Analysis: Evaluating competitive marketing effectiveness. Boston, Dordrecht, London : Kluwer. Hartmann, M. (2005): Gravitationsmodelle als Verfahren der Standortanalyse im Einzelhandel. Statistik Regional Electronic Papers, 02/2005. Halle. Huff, D. L./McCallum, D. (2008): Calibrating the Huff Model Using ArcGIS Business Analyst. ESRI White Paper, September 2008. Wieland, T. (2015): Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.

See Also

ijmatrix.create

Examples

Run this code
data(grocery1)
# Loads the data
mymcidata <- ijmatrix.create (grocery1, "plz_submarket", "store_code")
# Creates an interaction matrix with market shares based on the frequencies 
# of visited grocery stores and saves results directly in a new dataset
mymcidata$freq_ij_corr <- var.correct(mymcidata$freq_ij_abs, 1)
# Corrects the frequency variable (no zero or negative values allowed)
mymcidata_shares <- ijmatrix.shares(mymcidata, "plz_submarket", "store_code", "freq_ij_corr")
# Calculates market shares based on the corrected frequencies
# and saves the results as a new dataset

Run the code above in your browser using DataLab