Learn R Programming

MCI (version 1.2.0)

mci.transmat: Log-centering transformation of an MCI interaction matrix

Description

This function applies the log-centering transformation to the variables in a given MCI interaction matrix.

Usage

mci.transmat(mcidataset, submarkets, suppliers, mcivariable1, ..., show_proc = FALSE)

Arguments

mcidataset
an interaction matrix which is a data.frame containing the submarkets, suppliers and the regarded variables (e.g. the observed market shares, $p_{ij}$, and the explanatory variables)
submarkets
the column in the interaction matrix mcidataset containing the submarkets
suppliers
the column in the interaction matrix mcidataset containing the suppliers
mcivariable1
the column of the first variable to be transformed, numeric and positive (or dummy [1,0])
...
the columns of other variables to be transformed, numeric and positive (or dummy [1,0])
show_proc
logical argument that indicates if the function prints messages about the state of process during the work (e.g. “Processing variable xyz ...” or “Variable xyz is regarded as dummy variable”). Default: show_proc = FALSE (messages off)

Value

Returns a new data.frame with regression-ready data where the input variables are transformed by the the log-centering transformation. The names of the input variables are passed to the new data.frame marked with a "_t" to indicate that they were transformed (e.g. "shares_t" is the transformation of "shares").

Details

The input dataset is transformed to regression-ready data with the log-centering transformation by Nakanishi/Cooper (1974). The resulting data.frame can be fitted with the lm() function (to combine these two steps in one, use mci.fit()). The log-centering transformation can be regarded as the key concept of the MCI model because it enables the model to be estimated by OLS (ordinary least squares) regression. The function identifies dummy variables which are not transformed (because they do not have to be).

References

Huff, D. L./Batsell, R. R. (1975): “Conceptual and Operational Problems with Market Share Models of Consumer Spatial Behavior”. In: Advances in Consumer Research, 2, p. 165-172.

Huff, D. L./McCallum, D. (2008): “Calibrating the Huff Model Using ArcGIS Business Analyst”. ESRI White Paper, September 2008. https://www.esri.com/library/whitepapers/pdfs/calibrating-huff-model.pdf

Nakanishi, M./Cooper, L. G. (1974): “Parameter Estimation for a Multiplicative Competitive Interaction Model - Least Squares Approach”. In: Journal of Marketing Research, 11, 3, p. 303-311.

Wieland, T. (2013): “Einkaufsstaettenwahl, Einzelhandelscluster und raeumliche Versorgungsdisparitaeten - Modellierung von Marktgebieten im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten”. In: Schrenk, M./Popovich, V./Zeile, P./Elisei, P. (eds.): REAL CORP 2013. Planning Times. Proceedings of 18th International Conference on Urban Planning, Regional Development and Information Society. Schwechat. p. 275-284. http://www.corp.at/archive/CORP2013_98.pdf

Wieland, T. (2015): “Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens”. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.

See Also

mci.fit, mci.transvar

Examples

Run this code
data(ce)
# Loads the data
mci.transmat (ce, "origin_code", "store_code", "ms_obs", "traveltime", "salesarea", 
"conc_all", "conc_comp")
# Output: submarkets (origins), store codes and transformations
# of "ms_obs", "traveltime", "salesarea", "conc_all" and "conc_comp"

transf_mcimat <- mci.transmat (ce, "origin_code", "store_code", "ms_obs", "traveltime", 
"salesarea", "conc_all", "conc_comp")
# Save in a new data frame called "transf_mcimat"

Run the code above in your browser using DataLab