Learn R Programming

MCI (version 1.0.1)

ijmatrix.create: Interaction matrix with market shares

Description

Creation of an interaction matrix with market shares ($p_{ij}$) of every supplier ($j$) in every submarket ($i$) based on the frequencies in the raw data (e.g. household or POS survey).

Usage

ijmatrix.create(rawdataset, submarkets, suppliers)

Arguments

rawdataset
a data.frame containing the raw data
submarkets
the column in the dataset containing the submarkets (e.g. ZIP codes), should be a factor
suppliers
the column in the dataset containing the suppliers (e.g. store codes), should be a factor

Value

  • An interaction matrix which is a data.frame containing the $i$ x $j$ combinations ('interaction'), the submarkets (column is named as in raw data), the suppliers (column is named as in raw data), the observed absolute frequencies of every $j$ in every $i$ ('freq_ij_abs'), the observed absolute frequencies in every $i$ ('freq_i_total') and the observed market shares of every $j$ in every $i$ ('p_ij_obs'). The first three variables are factors, the calculated values are numeric.

Details

This function creates an interaction matrix for all $i$ submarkets (e.g. geographical regions) and all $j$ suppliers (e.g. store locations). An interaction matrix is a special case of table where every row is an $i$ x $j$ combination and the market shares of $j$ in $i$ ($p_{ij}$) are saved in a new column. An interaction matrix is the base for MCI analyses. In the MCI model the dependent variable is the market share of the $j$ suppliers in the $i$ submarkets, in which the shares are logically consistent (that means: 0 < $p_{ij}$ < 1, $\sum_{j=1}^n{p_{ij} = 1}$).

References

Cooper, L. G./Nakanishi, M. (1988): Market-Share Analysis: Evaluating competitive marketing effectiveness. Boston, Dordrecht, London : Kluwer. Huff, D. L./McCallum, D. (2008): Calibrating the Huff Model Using ArcGIS Business Analyst. ESRI White Paper, September 2008. Wieland, T. (2015): Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.

See Also

ijmatrix.shares

Examples

Run this code
data(grocery1)
# Loads the data
ijmatrix.create (grocery1, "plz_submarket", "store_code")
# Creates an interaction matrix with local market shares

mynewmcidata <- ijmatrix.create (grocery1, "plz_submarket", "store_code")
# Save results directly in a new dataset

Run the code above in your browser using DataLab