mci.transvar(mcidataset, submarkets, suppliers, mcivariable,
output_ij = FALSE, output_var = "numeric", show_proc = FALSE, check_df = TRUE)data.frame containing the submarkets, suppliers and the regarded variables (e.g. the observed market shares, $p_{ij}$, and the explanatory variables)
mcidataset containing the submarkets
mcidataset containing the suppliers
data.frame with three columns (submarkets, suppliers, transformed variable) or a vector only with the transformed values (default is output_ij = FALSE)
output_ij = FALSE (default is output_var = "numeric", otherwise "list")
show_proc = FALSE (messages off)
check_df = TRUE (should not be changed, only for internal use))
data.frame with the transformed input variable and the submarkets/suppliers or a vector with the transformed values only. The name of the input variable is passed to the new data.frame marked with a "_t" to indicate that it was transformed (e.g. "shares_t" is the transformation of "shares").
mci.transmat(), for transformation and fitting use mci.fit()). The log-centering transformation can be regarded as the key concept of the MCI model because it enables the model to be estimated by OLS (ordinary least squares) regression. The function identifies dummy variables which are not transformed (because they do not have to be).
Huff, D. L./McCallum, D. (2008): Calibrating the Huff Model Using ArcGIS Business Analyst. ESRI White Paper, September 2008. https://www.esri.com/library/whitepapers/pdfs/calibrating-huff-model.pdf
Nakanishi, M./Cooper, L. G. (1974): Parameter Estimation for a Multiplicative Competitive Interaction Model - Least Squares Approach. In: Journal of Marketing Research, 11, 3, p. 303-311.
Wieland, T. (2013): Einkaufsstaettenwahl, Einzelhandelscluster und raeumliche Versorgungsdisparitaeten - Modellierung von Marktgebieten im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. In: Schrenk, M./Popovich, V./Zeile, P./Elisei, P. (eds.): REAL CORP 2013. Planning Times. Proceedings of 18th International Conference on Urban Planning, Regional Development and Information Society. Schwechat. p. 275-284. http://www.corp.at/archive/CORP2013_98.pdf
Wieland, T. (2015): Raeumliches Einkaufsverhalten und Standortpolitik im Einzelhandel unter Beruecksichtigung von Agglomerationseffekten. Theoretische Erklaerungsansaetze, modellanalytische Zugaenge und eine empirisch-oekonometrische Marktgebietsanalyse anhand eines Fallbeispiels aus dem laendlichen Raum Ostwestfalens/Suedniedersachsens. Geographische Handelsforschung, 23. 289 pages. Mannheim : MetaGIS.
mci.fit, mci.transmat
data(ce)
# Loads the data
mci.transvar (ce, "origin_code", "store_code", "ms_obs", output_ij=TRUE)
# Output: submarkets (origins), store codes and transformations of "ms_obs"
mci.transvar (ce, "origin_code", "store_code", "ms_obs")
# Output: a numeric vector containing the transformated values of "ms_obs"
transf_mcivar <- mci.transvar (ce, "origin_code", "store_code", "ms_obs", output_ij=TRUE)
# Save in a new data frame called "transf_mcivar"
Run the code above in your browser using DataLab